# Projekt-Controlling
> Umfasst alle Aktivitäten, um projektbezogene Abweichungen zwischen Plan und IST-Zustand aufzudecken

- Abweichungen und Erkenntnisse darauf fließen wieder in Planung ein
- Kontrolle in Form von Reviews, Audits, Tests

## Prozessgruppen
### Plan-Do-Check-Act (PDCA)
### PM Prozessgruppen
```plantuml
    @startuml
    scale 0.50

    left to right direction
    skinparam dpi 150
    
    skinparam state {
    BackgroundColor #96cf95
    BorderColor black
    FontName Helvetica
    RoundCorner 30
    Shadowing false
    LineThickness 0
    }
    [*] --> Initiierung
    Initiierung --> Planung
    Planung --> Initiierung
    Planung --> Controlling
    Controlling --> Planung
    Planung --> Umsetzung
    Controlling --> Umsetzung
    Umsetzung --> Controlling
    Controlling --> Abschluss
    Umsetzung --> Abschluss
    
    @enduml
```

#### Wirkungskreislauf
```plantuml
    @startuml
    scale 0.50

    skinparam dpi 150
    
    skinparam state {
    BackgroundColor #96cf95
    BorderColor black
    FontName Helvetica
    RoundCorner 30
    Shadowing false
    LineThickness 0
    }
    
    state 1 as "Setzen von Zielen"
    state 2 as "Festlegung von Plangrößen"
    state 3 as "Vorgabe der Ziele und Plangrößen"
    state PA as "Projektabwicklung"
    state 4 as "Messen der Zielerreichung (Ist-Werte)"
    state 5 as "Feststellung der Soll-/Ist-Abweichungen"
    state 6 as "Abweichungsanalyse"
    state 7 as "Beseitigung der Abweichungsursachen"
    
    1 -down-> 2
    2 -down-> 3
    3 -down-> PA
    PA -up-> 4
    4 -up-> 5
    5 -up-> 6
    6 -up-> 7
    7 -up-> 1
    7 -left-> 2
    7 --> PA
    
    @enduml
```

### Was wird kontrolliert?
- Projektarbeiten, Änderungen
- Leistung
- Ressourcen, Projektteam
- Termin
- Kosten
- Risiko
- Qualität
- Kommunikation

## Projektberichtswesen und Statusreporting
### Projektberichtswesen
- 3 Grundregeln
  - einheitlicher Aufbau
  - Informationsbedürfnisse des Empfängers berücksichtigen
  - objektive Interpretation

#### Statusberichte
- kurz und prägnant
- werden periodisch erstellt
- Inhalt
  - Zeitpunkt
  - Wie sieht das Projekt aus
    - Wie sollte es aussehen
  - Aufwandsmäßiger Stand
    - Restaufwand
  - Gründe für Abweichungen
  - Maßnahmen (Vorschläge/Anträge des PL)
  - Konsquenzen
  - Top 5
    - Risiken, Probleme, Unregelmäßigkeiten
  - Hauptaktivitäten der nächsten Berichtsperiode
  - Personalsituation
- Beispiel:
  - ![image_926.png](image_926.png)

> Grundlage für die Phase Check des [PDCA](#plan-do-check-act-pdca)

```plantuml
    @startuml
    scale 0.50

    skinparam dpi 150
    
    skinparam state {
    BackgroundColor #96cf95
    BorderColor black
    FontName Helvetica
    RoundCorner 30
    Shadowing false
    LineThickness 0
    }
    
    state 1 as "Statusbericht Teilprojekte"
    state 2 as "Konsolidierter Statusbericht"
    state 3 as "Statusbericht"
    state 4 : Projektbasisdaten (bspw. Gesamtaufwand, Start- und Endzeit, ...)
    state 4 : Daten der Resplanung (Meilensteine, Aufwand, ...)
    state 4 : geplante Arbeitsergebnisse der nächsten Berichtszeitperiode
    state 4 as "Baseline Info"
    state 5 as "ToDo - Liste / Agenda"
    state 6 as "PL - Meeting"
    state 7 as "PL - Protokoll"
    
    1 -up-> 2
    2 -up-> 3
    2 -up-> 4
    1 -right-> 5
    5 -u-> 6
    6 -u-> 7
    7 --> 5
    
    @enduml
```

#### Verschiedene Ebenen von Berichten
![image_925.png](image_925.png)


## Meilensteintrendanalyse
- Methode zur Überwachung des inhaltlichen Projektfortschritts
- frühzeitige Erkennung von Verzögerungen
  - Korrekturmaßnahmen einleiten
- ![image_927.png](image_927.png)
- Vorgehen
  - Y-Achse: geplante Meilensteine mit Terminen
  - X-Achse: MS-Terminwerte des neusten Planungswerts
    - bei jedem Bericht kann analysiert werden, ob man im Plan ist

## Earned Value Analysis (EVA) / Management
### EVA
- Instrument zur Statusbewertung für strategische Entscheidungen
- Ziel
  - Voraussage Projekterfolg
    - _finanziell, zeitlich_
- Fortschrittsbewertung
  - anhand geleisteter Arbeit
  - nicht aufgrund des Sachfortschritts
- Voraussetzung
  - umfangreiche Projektplanung

| **Abk** | **Name**                            | **Formel**                  | **Bedeutung**                                                                                                                |
|---------|-------------------------------------|-----------------------------|------------------------------------------------------------------------------------------------------------------------------|
| PV      | Planned Value                       |                             | Budget                                                                                                                       |
| SAC     | Schedule at Completion<br/>Laufzeit |                             | ursprünglich geplante Fertigstelldauer (Datum)                                                                               |
| AC      | Actual Cost                         |                             | Aktueller Aufwand                                                                                                            |
| EV      | Earned Value                        | $EP*AC[%]$                  | Betrag für die Arbeit an einem Arbeitspaket, die bis zu einem bestimmten Zeitraum tatsächlich verrichtet wurde               |
| CV      | Cost Variance                       | $EV-AC$                     | Wie teuer sind wir tatsächlich?<br/> $<0$→schlechter als Plan                                                                |
| CPI     | Cost-Performance Index              | $EV/AC$                     | Maß für Kostenstatus/Wirtschaftlichkeit                                                                                      |
| SV      | Schedule Variance                   | $EV-PV$                     | Wie gut kommen wir vorran?                                                                                                   |
| SPI     | Schedule-Performance Index          | $EV/PV$                     | Maß für Projektfortschritt<br/> $<1$→schlechter als geplant                                                                  |
| BAC     | Budget at Completion                |                             | Geplante Gesamtkosten                                                                                                        |
| EAC     | Estimated Cost at Completion        | $BAC/CPI$<br/>$AC+(BAC-EV)$ | Lineare Prognose→ Abweichung setzt sich proportional fort<br/>Additive Prognose→Bislang aufgetretene Abweichung ist einmalig |
| ETC     | Estimate to Completion              | $EAC-AC$                    | Restkosten bis zum Ende des Projekts                                                                                         |
| TEAC    | Time Estimate at Completion         | $SAC/SPI$                   | Abschätzung der Laufzeit                                                                                                     |


#### Beispiel EVA
![image_930.png](image_930.png)

#### Übung EVA
- BAC = 120000€
- SAC = 1 Jahr
- Am Ende des 4. Monats: 40% der Arbeit erledigt, 530000€ verbraucht

- $EV = 40% * BAC = 48000€$
- $PV = 4*10000€ = 40000€$
- $AC = 53000€$
- $CV = 48000€-53000€ = -5000€$
- $CPI = 48000€ / 53000€ = 0,906$
- $SV = 40%-4/12 = 0,667$
- $SPI = 40%/(4/12) = 1,3$
- $EAC$ 
  - $linear = BAC/CPI = 120000/(-5000) = -24000$
  - $additiv = AC + (BAC-EV) = 53000€+(12000€-48000€)= 72000€$
- $TEAC = SAC/SPI = 1[Jahr] / 1,3 = 0,769[Jahre]$

#### Übungen
![image_931.png](image_931.png)
![image_932.png](image_932.png)
![image_933.png](image_933.png)


## Change Management
> **ACHTUNG**
> 
> Änderungsmanagement $\neq$ Veränderungsmanagement

| Änderungsmanagement                                                  | Changemanagement                                       |
|----------------------------------------------------------------------|--------------------------------------------------------|
| Änderung von Prozessen, physischen/materiellen Mitteln und Produkten | Änderung von Strukturen, Menschen und Einzelfunktionen |
| kontrolliertes, bewusstes Ändern der Pläne                           | geplante organisatorische Veränderung                  |
| Erfolgt durch eine definierte Instanz (PL / Change Control Board)    |                                                        |

**Changemanagement**
- Summe aller Maßnahmen, die durch das Projekt beweirten Veränderungen in kürzester Zeit zu adaptieren
- ![image_934.png](image_934.png)
- 7 Schritte der emotionalen Verarbeitung
  - ![image_935.png](image_935.png)
- In Projekten
  - ![image_936.png](image_936.png)
    - Changerequest CR
      - _Antrag auf eine Änderung des im Projektauftrag fixierten Zielrahmens bzw. der im Konzept festgelegten und verabschiedeten Anforderungen an das zu realisierende Produkt._
- Beispiele
  - Beim Rasenmähen
    - CR: Termin-Verzug und Kostenerhöhung
      - Viel Unrat wird enddeckt, soll er den kostenpflichtig entfernen?
    - Organizational Change Management
      - Nachbarschaft ist gegen das Mähen des Rasens
        - 12-14Uhr ist Lärm zu vermeiden
      - Unrat: Gäste werden gebeten, gemeinsam Rasen zu säubern